<?xml version="1.0"?>
<?xml-stylesheet type="text/xsl" href="/rss.xsl.xml"?>
<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/">
<channel>
    <title>Changes in aes</title>
    <link>http://nxr.netbsd.org/rss/src/tests/sys/crypto/aes/</link>
    <description></description>
    <language>en</language>
    <copyright>Copyright 2005</copyright>
    <generator>Java</generator>
    
<item>
    <title>Needs the same compiler bug workaround as the kernel.</title>
    <description></description>
    <pubDate>Mon Nov 24 16:00:00 UTC 2025</pubDate>
    <dc:creator>nia</dc:creator>
</item>

<item>
    <title>aes(9): Rewrite x86 SSE2 implementation.<br/><br/>This computes eight AES_k instances simultaneously, using the<br/>bitsliced 32-bit aes_ct logic which computes two blocks at a time in<br/>uint32_t arithmetic, vectorized four ways.<br/><br/>Previously, the SSE2 code was a very naive adaptation of aes_ct64,<br/>which computes four blocks at a time in uint64_t arithmetic, without<br/>any 2x vectorization -- I did it at the time because:<br/><br/>(a) it was easier to get working,<br/>(b) it only affects really old hardware with neither AES-NI nor SSSE3<br/>    which are both much much faster.<br/><br/>But it was bugging me that this was a kind of dumb use of SSE2.<br/><br/>Substantially reduces stack usage (from ~1200 bytes to ~800 bytes)<br/>and should approximately double throughput for CBC decryption and for<br/>XTS encryption/decryption.<br/><br/>I also tried a 2x64 version but cursory performance measurements<br/>didn't reveal much benefit over 4x32.  (If anyone is interested in<br/>doing more serious performance measurements, on ancient hardware for<br/>which it might matter, I also have the 2x64 code around.)<br/><br/>Prompted by:<br/><br/>PR kern/59774: bearssl 32-bit AES is too slow, want 64-bit optimized<br/>version in kernel</title>
    <description></description>
    <pubDate>Sun Nov 23 22:00:00 UTC 2025</pubDate>
    <dc:creator>riastradh</dc:creator>
</item>
</channel></rss>

